DSStorageManager class
Central manager for storage providers in DartStream
Constructors
- DSStorageManager(String providerName)
- Initialize the manager with one of the registered providers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteFile(
String path) → Future< void> -
dispose(
) → Future< void> -
downloadFile(
String path) → Future< List< int> > -
getSignedUrl(
String path, {Duration? expiry}) → Future< String> -
initialize(
Map< String, dynamic> config) → Future<void> -
listFiles(
String path, {bool recursive = false}) → Future< List< String> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
uploadFile(
String path, List< int> data, {Map<String, dynamic> ? metadata}) → Future<String>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- enableDebugging ↔ bool
-
getter/setter pair
Static Methods
-
getProviderMetadata(
String name) → DSStorageProviderMetadata? - Get metadata for a specific provider
-
getRegisteredProviderNames(
) → List< String> - Get all registered provider names
-
registerProvider(
String name, DSStorageProvider provider, DSStorageProviderMetadata metadata) → void - Register a new storage provider